@@ -87,7 +87,7 @@ bool Installation::readConfig(const KConfigGroup &group)
     // also, ensure wallpapers are decompressed into subdirectories
     // this ensures that wallpapers with multiple resolutions continue to function
     // as expected
-    if (xdgTargetDirectory == QStringLiteral("wallpapers")) {
+    if (xdgTargetDirectory == QLatin1String("wallpapers")) {
         uncompression = QStringLiteral("subdir");
     }
 
@@ -328,7 +328,7 @@ void KNSCore::Installation::install(KNSCore::EntryInternal entry, const QString&
     };
     if (!postInstallationCommand.isEmpty()) {
         QProcess* p = runPostInstallationCommand(installedFiles.size() == 1 ? installedFiles.first() : targetPath);
-        connect(p, static_cast<void(QProcess::*)(int)>(&QProcess::finished), this, installationFinished);
+        connect(p, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, installationFinished);
     } else {
         installationFinished();
     }
@@ -535,10 +535,10 @@ QStringList Installation::installDownloadedFileAndUncompress(const KNSCore::Entr
 
             if (QFile::exists(installpath) && QDir::tempPath() != installdir) {
                 if (!update) {
-                    Question question(Question::ContinueCancelQuestion);
-                    question.setQuestion(i18n("Overwrite existing file?") + QStringLiteral("\n'") + installpath + QLatin1Char('\''));
-                    question.setTitle(i18n("Download File"));
-                    if(question.ask() != Question::ContinueResponse) {
+                    Question question(Question::YesNoQuestion);
+                    question.setQuestion(i18n("This file already exists on disk (possibly due to an earlier failed download attempt). Continuing means overwriting it. Do you wish to overwrite the existing file?") + QStringLiteral("\n'") + installpath + QLatin1Char('\''));
+                    question.setTitle(i18n("Overwrite File"));
+                    if(question.ask() != Question::YesResponse) {
                         return QStringList();
                     }
                 }
@@ -571,8 +571,10 @@ QProcess* Installation::runPostInstallationCommand(const QString &installPath)
     qCDebug(KNEWSTUFFCORE) << "Run command: " << command;
 
     QProcess* ret = new QProcess(this);
-    connect(ret, static_cast<void(QProcess::*)(int)>(&QProcess::finished), this, [this, command](int exitcode){
-        if (exitcode) {
+    connect(ret, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, [this, command](int exitcode, QProcess::ExitStatus status) {
+        if (status == QProcess::CrashExit) {
+            qCCritical(KNEWSTUFFCORE) << "Process crashed with command: " << command;
+        } else if (exitcode) {
             qCCritical(KNEWSTUFFCORE) << "Command '" << command << "' failed with code" << exitcode;
         }
         sender()->deleteLater();
@@ -590,7 +592,8 @@ void Installation::uninstall(EntryInternal entry)
     entry.setStatus(KNS3::Entry::Deleted);
 
     if (!uninstallCommand.isEmpty()) {
-        foreach (const QString &file, entry.installedFiles()) {
+        const auto lst = entry.installedFiles();
+        for (const QString &file : lst) {
             QFileInfo info(file);
             if (info.isFile()) {
                 QString fileArg(KShell::quoteArg(file));
@@ -608,7 +611,8 @@ void Installation::uninstall(EntryInternal entry)
         }
     }
 
-    foreach (const QString &file, entry.installedFiles()) {
+    const auto lst = entry.installedFiles();
+    for (const QString &file : lst) {
         if (file.endsWith(QLatin1Char('/'))) {
             QDir dir;
             bool worked = dir.rmdir(file);
@@ -651,7 +655,8 @@ void Installation::slotInstallationVerification(int result)
 QStringList Installation::archiveEntries(const QString &path, const KArchiveDirectory *dir)
 {
     QStringList files;
-    foreach (const QString &entry, dir->entries()) {
+    const auto lst = dir->entries();
+    for (const QString &entry : lst) {
         const auto currentEntry = dir->entry(entry);
 
         const QString childPath = path + QLatin1Char('/') + entry;
